# RAMSLIBS 
## Useful tools for working with RAMS data

[![Documentation Status](https://readthedocs.org/projects/ramslibs/badge/?version=stable)](https://ramslibs.readthedocs.io/en/latest/?badge=stable)
[![DOI](https://zenodo.org/badge/176599749.svg)](https://zenodo.org/badge/latestdoi/176599749)



Documentation can be [found here](https://ramslibs.readthedocs.io/en/stable)

Install with:
```
pip install ramslibs
``` 
RAMSlibs is distributed under an [MIT License](LICENSE)
